.. webapi-error::
   :instance: reviewboard.webapi.errors.MISSING_USER_KEY

   Review Board attempted to authenticate with a repository that required a
   public SSH key, but no SSH key was configured on Review Board.
